#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-DVNEHy3LCCE9iC1Qc3jNOD
key:                  lsp-2.2.0.0-DVNEHy3LCCE9iC1Qc3jNOD
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  0ba62813693cab043b706ecc2d6578d8
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-6kjARmZz5SuJJynM8KbziL:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-6kjARmZz5SuJJynM8KbziL:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-6kjARmZz5SuJJynM8KbziL:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-6kjARmZz5SuJJynM8KbziL:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-DVNEHy3LCCE9iC1Qc3jNOD
depends:
    aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf
    attoparsec-0.14.4-3CmiIm11iun2BHKDR4ovn7 base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-GuSJsTgYt5FFsUUXhUW401
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    lens-5.3.4-AArhojR1bHQDPd0CW0dSET
    lens-aeson-1.2.3-CpvTsokJAKT4oaewHiEZul
    lsp-types-2.0.2.0-6kjARmZz5SuJJynM8KbziL mtl-2.3.1
    prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    row-types-1.0.1.2-HQm5JaZ8zht4jnbniISK4M
    sorted-list-0.2.3.1-8C8E8v9lixLLe0zF39SovV stm-2.5.1.0
    temporary-1.3-imd8AcD6Pg3Lf1V6ZsYLS text-2.0.2
    text-rope-0.3-2tUYMQibjWmGZFFzmnf5kt transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    uuid-1.3.16-E14zVMKNOKa6MWWZ9x240y

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

